Learn R Programming

Rparadox (version 0.2.2)

Rparadox-package: Rparadox: Read Paradox Database Files into R

Description

Provides a simple and efficient way to read data from Paradox database files (.db) directly into R as modern 'tibble' data frames. It uses the underlying 'pxlib' C library, to handle the low-level file format details and provides a clean, user-friendly R interface.

Arguments

Author

Maintainer: Daniil Popov popov.daniil@gmail.com

See Also